==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/template/authorization/AuthorizationSpecFluent.java <==
package me.snowdrop.istio.mixer.template.authorization;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Boolean;

public interface AuthorizationSpecFluent<A extends AuthorizationSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAction instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.mixer.template.authorization.Action getAction();
    public me.snowdrop.istio.mixer.template.authorization.Action buildAction();
    public A withAction(me.snowdrop.istio.mixer.template.authorization.Action action);
    public Boolean hasAction();
    public AuthorizationSpecFluent.ActionNested<A> withNewAction();
    public AuthorizationSpecFluent.ActionNested<A> withNewActionLike(me.snowdrop.istio.mixer.template.authorization.Action item);
    public AuthorizationSpecFluent.ActionNested<A> editAction();
    public AuthorizationSpecFluent.ActionNested<A> editOrNewAction();
    public AuthorizationSpecFluent.ActionNested<A> editOrNewActionLike(me.snowdrop.istio.mixer.template.authorization.Action item);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    
/**
 * This method has been deprecated, please use method buildSubject instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.mixer.template.authorization.Subject getSubject();
    public me.snowdrop.istio.mixer.template.authorization.Subject buildSubject();
    public A withSubject(me.snowdrop.istio.mixer.template.authorization.Subject subject);
    public Boolean hasSubject();
    public AuthorizationSpecFluent.SubjectNested<A> withNewSubject();
    public AuthorizationSpecFluent.SubjectNested<A> withNewSubjectLike(me.snowdrop.istio.mixer.template.authorization.Subject item);
    public AuthorizationSpecFluent.SubjectNested<A> editSubject();
    public AuthorizationSpecFluent.SubjectNested<A> editOrNewSubject();
    public AuthorizationSpecFluent.SubjectNested<A> editOrNewSubjectLike(me.snowdrop.istio.mixer.template.authorization.Subject item);

    public interface ActionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.mixer.template.authorization.ActionFluent<AuthorizationSpecFluent.ActionNested<N>>{

        
    public N and();    public N endAction();
}
    public interface SubjectNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.mixer.template.authorization.SubjectFluent<AuthorizationSpecFluent.SubjectNested<N>>{

        
    public N and();    public N endSubject();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/template/authorization/AuthorizationSpecFluent.java <==
package me.snowdrop.istio.mixer.template.authorization;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface AuthorizationSpecFluent<A extends AuthorizationSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAction instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.mixer.template.authorization.Action getAction();
    public me.snowdrop.istio.mixer.template.authorization.Action buildAction();
    public A withAction(me.snowdrop.istio.mixer.template.authorization.Action action);
    public Boolean hasAction();
    public AuthorizationSpecFluent.ActionNested<A> withNewAction();
    public AuthorizationSpecFluent.ActionNested<A> withNewActionLike(me.snowdrop.istio.mixer.template.authorization.Action item);
    public AuthorizationSpecFluent.ActionNested<A> editAction();
    public AuthorizationSpecFluent.ActionNested<A> editOrNewAction();
    public AuthorizationSpecFluent.ActionNested<A> editOrNewActionLike(me.snowdrop.istio.mixer.template.authorization.Action item);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSubject instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.mixer.template.authorization.Subject getSubject();
    public me.snowdrop.istio.mixer.template.authorization.Subject buildSubject();
    public A withSubject(me.snowdrop.istio.mixer.template.authorization.Subject subject);
    public Boolean hasSubject();
    public AuthorizationSpecFluent.SubjectNested<A> withNewSubject();
    public AuthorizationSpecFluent.SubjectNested<A> withNewSubjectLike(me.snowdrop.istio.mixer.template.authorization.Subject item);
    public AuthorizationSpecFluent.SubjectNested<A> editSubject();
    public AuthorizationSpecFluent.SubjectNested<A> editOrNewSubject();
    public AuthorizationSpecFluent.SubjectNested<A> editOrNewSubjectLike(me.snowdrop.istio.mixer.template.authorization.Subject item);

    public interface ActionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.mixer.template.authorization.ActionFluent<AuthorizationSpecFluent.ActionNested<N>>{

        
    public N and();    public N endAction();
}
    public interface SubjectNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.mixer.template.authorization.SubjectFluent<AuthorizationSpecFluent.SubjectNested<N>>{

        
    public N and();    public N endSubject();
}


}
